from dataclasses import dataclass
from enum import Enum

from sqlalchemy import JSON as Sql_JSON, Integer
from sqlalchemy import Enum as Sql_Enum
from sqlalchemy import ForeignKey, String
from sqlalchemy.orm import Mapped, mapped_column, relationship

from src.entity.database import db


# 账号类型枚举
class AccountType(Enum):
    ky = 0
    hth = 1
    jy = 2
    aty = 3 #爱体育


@dataclass
class Account(db.Base):
    __tablename__ = 'ky_account'

    id: Mapped[db.int_pk]
    username: Mapped[db.str_required_unique] = mapped_column(comment='账号')
    password: Mapped[db.str_required] = mapped_column(comment='密码')
    type: Mapped[AccountType] = mapped_column(Sql_Enum(AccountType), default=AccountType.ky, nullable=False,
                                              comment='类型 ky hth jy aty')
    name: Mapped[str] = mapped_column(String(64), nullable=True, comment='别名')
    url: Mapped[str] = mapped_column(String(128), nullable=False, comment='url')
    headers: Mapped[Sql_JSON] = mapped_column(Sql_JSON, nullable=True, comment='headers')
    user_id: Mapped[int] = mapped_column(ForeignKey('ky_user.id'),
                                         nullable=False, comment='关联的用户id')
    user: Mapped['user.User'] = relationship('user.User', back_populates='accounts')
    status: Mapped[int] = mapped_column(Integer, nullable=True, comment='账号状态,默认0 禁用', default=0)
