from PyQt6.QtCore import Qt
from PyQt6.QtGui import QFont, QIcon, QPixmap
from PyQt6.QtWidgets import QHBoxLayout, QLabel, QToolButton, QWidget


class CustomTitleBar(QWidget):
    def __init__(self, parent):
        super().__init__(parent)
        self.parent = parent
        self.mousePressed = False
        self.setup_ui()

    def setup_ui(self):
        self.layout = QHBoxLayout()
        self.layout.setContentsMargins(0, 0, 0, 0)
        self.layout.setSpacing(0)

        self.setup_icon_label()
        self.setup_title_label()
        self.setup_buttons()

        self.setLayout(self.layout)

    def setup_icon_label(self):
        self.iconLabel = QLabel(self)
        self.iconLabel.setFixedSize(32, 32)
        iconPixmap = QPixmap('icons:icon.png').scaled(24, 24, Qt.AspectRatioMode.KeepAspectRatio)
        self.iconLabel.setPixmap(iconPixmap)
        self.layout.addWidget(self.iconLabel)

    def setup_title_label(self):
        font = QFont()
        font.setPointSize(11)
        self.titleLabel = QLabel(f"{self.parent.username}的小工具")
        self.titleLabel.setFont(font)
        self.titleLabel.setAlignment(Qt.AlignmentFlag.AlignLeft | Qt.AlignmentFlag.AlignVCenter)
        self.layout.addWidget(self.titleLabel, 1)

    def setup_buttons(self):
        self.stayOnTopButton = self.create_tool_button('icons:top.svg', self.toggle_stay_on_top)
        self.minimizeButton = self.create_tool_button('icons:min.svg', self.parent.showMinimized)
        self.maximizeButton = self.create_tool_button('icons:max.svg', self.toggle_maximize)
        self.closeButton = self.create_tool_button('icons:close.svg', self.parent.close)
        self.closeButton.setObjectName("closeButton")

    def create_tool_button(self, icon_path, callback):
        button = QToolButton()
        button.setIcon(QIcon(icon_path))
        button.setFixedSize(32, 32)
        button.clicked.connect(callback)
        self.layout.addWidget(button)
        return button

    def mousePressEvent(self, event):
        if event.buttons() == Qt.MouseButton.LeftButton:
            self.mousePressed = True
            self.mousePos = event.globalPosition().toPoint()

    def mouseMoveEvent(self, event):
        if self.mousePressed:
            self.parent.move(self.parent.pos() + (event.globalPosition().toPoint() - self.mousePos))
            self.mousePos = event.globalPosition().toPoint()

    def mouseReleaseEvent(self, event):
        self.mousePressed = False

    def toggle_stay_on_top(self):
        if self.parent.windowFlags() & Qt.WindowType.WindowStaysOnTopHint:
            self.parent.setWindowFlags(self.parent.windowFlags() & ~Qt.WindowType.WindowStaysOnTopHint)
            self.stayOnTopButton.setIcon(QIcon('icons:top.svg'))
        else:
            self.parent.setWindowFlags(self.parent.windowFlags() | Qt.WindowType.WindowStaysOnTopHint)
            self.stayOnTopButton.setIcon(QIcon('icons:normal.svg'))
        self.parent.show()

    def toggle_maximize(self):
        if self.parent.isMaximized():
            self.parent.showNormal()
            self.maximizeButton.setIcon(QIcon('icons:max.svg'))  # Update icon if needed
        else:
            self.parent.showMaximized()
            self.maximizeButton.setIcon(QIcon('icons:max.svg'))  # Update icon if needed
